==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/method.uninstall.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: FrontEndUsers (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

//
// remove tables
//
$db = cmsms()->GetDb();
$dict = NewDataDictionary($db);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_APIKEYS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_ACTIVITIES );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_CHECKINS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_LOG );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_LEADERBOARD );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_LEADERBOARD_MEMBERS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_BADGES );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_BADGES_USERS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_FRIENDSHIPS );
$dict->ExecuteSQLArray($sqlarray);


//
// remove events
//

//
// remove permissions
//
$this->RemovePermission(CGSocialApp::PERMISSION);

//
// remove templates
//
$this->DeleteTemplate();

//
// remove preferences
//
$this->RemovePreference();

//
// remove events
//
$this->RemoveEvent('OnCheckin');
$this->RemoveEvent('OnUpdateCheckin');
$this->RemoveEvent('PreDeleteCheckin');
$this->RemoveEvent('PostDeleteCheckin');

//
// Remove jobs
//
$jobs = cgjobmgr_utils::get_jobs(array('name'=>$this->GetName().'*'));
if( is_array($jobs) && count($jobs) ) {
  foreach( $jobs as &$job ) {
    $job->delete();
  }
}

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/method.uninstall.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: FrontEndUsers (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

//
// remove tables
//
$db = cmsms()->GetDb();
$dict = NewDataDictionary($db);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_APIKEYS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_ACTIVITIES );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_CHECKINS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_LOG );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_LEADERBOARD );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_LEADERBOARD_MEMBERS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_BADGES );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_BADGES_USERS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_FRIENDSHIPS );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( CGSOCIAL_TABLE_FAVORITES );
$dict->ExecuteSQLArray($sqlarray);


//
// remove events
//

//
// remove permissions
//
$this->RemovePermission(CGSocialApp::PERMISSION);

//
// remove templates
//
$this->DeleteTemplate();

//
// remove preferences
//
$this->RemovePreference();

//
// remove events
//
foreach( cgsa_utils::get_events() as $event ) {
  $this->RemoveEvent($event);
}

//
// Remove jobs
//
$jobs = cgjobmgr_utils::get_jobs(array('name'=>$this->GetName().'*'));
if( is_array($jobs) && count($jobs) ) {
  foreach( $jobs as &$job ) {
    $job->delete();
  }
}

#
# EOF
#
?>
